@@ -22,8 +22,9 @@
 import os
 import re
 
+import config as gol
 from libs import bflb_utils
-from libs.bflb_utils import app_path, chip_path, flash_dict
+from libs.bflb_utils import app_path, chip_path, conf_sign
 from libs.bflb_configobj import BFConfigParser
 
 
@@ -34,7 +35,7 @@ def get_int_mask(pos, length):
     return int(mask, 2)
 
 
-def update_data_from_cfg(config_keys, config_file):
+def update_flash_para_from_cfg(config_keys, config_file):
     section = "FLASH_CFG"
     # bflb_utils.printf("Updating data according to <" + config_file + "[" + section + "]>")
     cfg = BFConfigParser()
@@ -85,12 +86,15 @@ def update_data_from_cfg(config_keys, config_file):
 
 
 def update_flash_cfg_data_do(chipname, chiptype, flash_id):
-    cfg_dir = app_path + "/utils/flash-conf/" + flash_dict[chipname] + '/'
+    if conf_sign:
+        cfg_dir = app_path + "/utils/flash/" + chipname + '/'
+    else:     
+        cfg_dir = app_path + "/utils/flash/" + gol.flash_dict[chipname] + '/'
     sub_module = __import__("libs." + chiptype, fromlist=[chiptype])
     conf_name = sub_module.flash_select_do.get_suitable_file_name(cfg_dir, flash_id)
     if os.path.isfile(cfg_dir + conf_name) == False:
         return None, None, None, None, None
-    return update_data_from_cfg(sub_module.bootheader_cfg_keys.bootheader_cfg_keys, cfg_dir + conf_name)
+    return update_flash_para_from_cfg(sub_module.bootheader_cfg_keys.bootheader_cfg_keys, cfg_dir + conf_name)
 
 
 def flash_bootheader_config_check(chipname, chiptype, flashid, file, parafile):
